import 'package:flutter/material.dart';

/// Animations types
enum AnimationType { normal, fadeIn }

/// Main class, [context] is ther Buildcontext

class SynapticTransitions {
  final BuildContext context;
  final Widget child;
  final AnimationType? animation;
  final Duration duration;
  final bool replacement;

  SynapticTransitions(
      {required this.context,
      required this.child,
      this.replacement = false,
      this.animation = AnimationType.normal,
      this.duration = const Duration(milliseconds: 300)}) {
    switch (animation) {
      case AnimationType.normal:
        _normalTransition();
        break;
      case AnimationType.fadeIn:
        _fadeInTransition();
        break;
      default:
    }
  }

  void _normalTransition() {
    final route = MaterialPageRoute(builder: (_) => child);
    (replacement) ? _pushReplacement(route) : _pushPage(route);
  }

  ///Navigation controller for fadein navigation
  void _fadeInTransition() {
    final route = PageRouteBuilder(
        pageBuilder: (_, __, ___) => child,
        transitionDuration: duration,
        transitionsBuilder: (_, animation, __, child) {
          return FadeTransition(
            child: child,
            opacity: Tween<double>(begin: 0.0, end: 1.0).animate(
                CurvedAnimation(parent: animation, curve: Curves.easeOut)),
          );
        });

    (replacement) ? _pushReplacement(route) : _pushPage(route);
  }

  ///Method to navigate with return capacity
  void _pushPage(Route route) => Navigator.push(context, route);

  ///Method to navigate without return capacity
  void _pushReplacement(Route route) =>
      Navigator.pushReplacement(context, route);
}
